==> apache-impala-4.3.0.tar.gz: apache-impala-4.3.0/fe/src/main/java/org/apache/impala/planner/SumProcessingCost.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.apache.impala.planner;

import com.google.common.base.Preconditions;

import org.apache.impala.util.MathUtil;

public class SumProcessingCost extends ProcessingCost {
  private final ProcessingCost cost1_;
  private final ProcessingCost cost2_;

  protected SumProcessingCost(ProcessingCost cost1, ProcessingCost cost2) {
    Preconditions.checkArgument(cost1.isValid(), "SumProcessingCost: cost1 is invalid!");
    Preconditions.checkArgument(cost2.isValid(), "SumProcessingCost: cost2 is invalid!");
    cost1_ = cost1;
    cost2_ = cost2;
  }

  @Override
  public long getTotalCost() {
    return MathUtil.saturatingAdd(cost1_.getTotalCost(), cost2_.getTotalCost());
  }

  @Override
  public boolean isValid() {
    return true;
  }

  @Override
  public ProcessingCost clone() {
    return new SumProcessingCost(cost1_, cost2_);
  }

  @Override
  public String getExplainString(String detailPrefix, boolean fullExplain) {
    StringBuilder output = new StringBuilder();
    output.append(detailPrefix).append("SumCost: ").append(getDetails());
    if (fullExplain) {
      String nextPrefix = detailPrefix + "  ";
      output.append("\n").append(cost1_.getExplainString(nextPrefix, true));
      output.append("\n").append(cost2_.getExplainString(nextPrefix, true));
    }
    return output.toString();
  }
}

==> apache-impala-4.5.0.tar.gz: apache-impala-4.5.0/fe/src/main/java/org/apache/impala/planner/SumProcessingCost.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package org.apache.impala.planner;

import com.google.common.base.Preconditions;

import org.apache.impala.util.MathUtil;

public class SumProcessingCost extends ProcessingCost {
  private final ProcessingCost cost1_;
  private final ProcessingCost cost2_;

  protected SumProcessingCost(ProcessingCost cost1, ProcessingCost cost2) {
    Preconditions.checkArgument(
        cost1.isValid(), "SumProcessingCost: cost1 is invalid! %s", cost1);
    Preconditions.checkArgument(
        cost2.isValid(), "SumProcessingCost: cost2 is invalid! %s", cost2);
    cost1_ = cost1;
    cost2_ = cost2;
  }

  @Override
  public long getTotalCost() {
    return MathUtil.saturatingAdd(cost1_.getTotalCost(), cost2_.getTotalCost());
  }

  @Override
  public boolean isValid() {
    return true;
  }

  @Override
  public ProcessingCost clone() {
    return new SumProcessingCost(cost1_, cost2_);
  }

  @Override
  public String getExplainString(String detailPrefix, boolean fullExplain) {
    StringBuilder output = new StringBuilder();
    output.append(detailPrefix).append("SumCost: ").append(getDetails());
    if (fullExplain) {
      String nextPrefix = detailPrefix + "  ";
      output.append("\n").append(cost1_.getExplainString(nextPrefix, true));
      output.append("\n").append(cost2_.getExplainString(nextPrefix, true));
    }
    return output.toString();
  }
}
